@@ -84,6 +84,9 @@ void
 free_rcptlist(struct rcptaddr *head)
 {
     int i;
+    if (head == NULL) {
+        return;
+    }
     for (i = 0; (head + i)->rcpt_addr != NULL; i++) {
 	if ((head + i)->rcpt_addr != NULL) {
 	    free((head + i)->rcpt_addr);
