@@ -86,10 +86,23 @@ struct mlfiPriv
     struct rcptaddr *mlfi_savebcc;
     int             mlfi_whitelist;
     sender_check_arg_t mlfi_sendercheck_arg;
+#ifdef __CUSTOMIZE2018
+    int             mlfi_subject_lang;
+    int             mlfi_sencstatus;
+    char            *mlfi_subject;
+    char            *mlfi_subjectf;
+#endif	// __CUSTOMIZE2018
 };
 
 pthread_t           child;
 
 void listvardump(struct rcptinfo *);
 
+#ifdef __CUSTOMIZE2018
+#define SBJLANG_EN	100
+#define SBJLANG_JP	200
+int check_enc_subject(struct mlfiPriv *, char *, char **);
+int check_str_mime(char *, char *, char **);
+#endif	// __CUSTOMIZE2018
+
 #endif	/* _MAILZIP_H_ */
