@@ -123,7 +123,7 @@ char *read_harmlessconf(char *file, void **pointer)
 
     for (nline = 1; fgets(line, MAX_CONFIG_LINE + 1, fp) != NULL; nline++) {
         command_list_t current_list = {NULL, NULL, NULL, NULL, 
-                                       -1, 0, 0, NULL, 0, NULL};
+                                       -1, 0, 0, NULL, NULL};
 
         tail = strchr(line, '\n');
         if (tail == NULL) {
@@ -533,7 +533,6 @@ int convert_alternative(GMimeObject *part, GMimeObject **new, harmless_proc_arg_
     GMimeMultipart *top;
 
     command_list_t *cp;
-    command_list_t *cp2;
     command_list_t *clist = arg->cfg->cf_harmlessconf;
 
 
@@ -645,7 +644,7 @@ int convert_extension(GMimeObject *part, GMimeObject **new, harmless_proc_arg_t
     filename = estimate_filename(part);
 
     /* 添付ファイル名の有無を判断 */
-    if (filename != "") {
+    if (filename[0] != '\0') {
         /* 拡張子を取得 */
         attachment_extension = strrchr(filename, '.');
 
