@@ -60,10 +60,12 @@
 #define PORT_MAX_LEN 5
 #define IP_MAX_LEN 15
 #define CONVERSION_STR_LEN 2
+#define EXTENSION_CHAR  "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789`~!@#$%^&*()_+-={}|[]:\\\";'<>?.,"
 
 struct search_res {
     char	*onetime_pass;
     DB		*rcpt_dbp;
+    DB		*ext_dbp;
     LDAP 	*ld;
     char	*userdn;
 };
@@ -76,7 +78,7 @@ struct person {
 
 int search_rcptaddr(struct config *, char *, struct rcptaddr *, struct rcptinfo **, struct rcptinfo **);
 int search_rcptaddr_delmode(struct config *, struct rcptaddr *, struct rcptinfo **, struct rcptinfo **);
-int add_enclist(struct rcptinfo ***, char *, char *, char *);
+int add_enclist(struct config *cfg, struct rcptinfo ***, char *, char *, char *, DB *, char *);
 int search_fromaddr_bdb(struct config *, char *);
 int search_subdomain_bdb(DB *, const char *, char *, char **, char **);
 int mk_passwd(char **, int);
@@ -91,5 +93,7 @@ int check_default_policy(int, struct search_res *, struct config *, char *, stru
 int search_rcptaddr_ldap(struct search_res *, struct config *, char *, struct rcptinfo **, struct rcptinfo **);
 int set_priority_addr (struct person *, struct berval **, struct berval **);
 char *str_tolower (char *);
+int check_validation_of_ext(struct config *, char *);
+int search_ext_bdb(DB *, const char *, char *, char **);
 
 #endif /*_SAMMA_POLICY_H_*/
