@@ -25,7 +25,7 @@
  */
 
 int sendmail();
-int passwd_sendmail(struct config *, char *, char *);
+int passwd_sendmail(struct config *, char *, char *, char *);
 int sendmail_with_gmime_object();
 extern int arg_split(char ***, char *);
 extern void arg_list_free(char **, int);
