@@ -37,7 +37,7 @@
 #include <dirent.h>
 #include <pthread.h>
 #include <libdgstr.h>
-#include <fcntl.h>
+#include <libdgmail.h>
 #include <fcntl.h>
 
 #include "mailzip_config.h"
@@ -53,7 +53,6 @@
 #ifdef __CUSTOMIZE2018
 #include <libmilter/mfapi.h>
 #include <syslog.h>
-#include <libdgmail.h>
 #include "mailzip.h"
 #define MLFIPRIV(ctx)        ((struct mlfiPriv *) smfi_getpriv(ctx))
 #endif	// __CUSTOMIZE2018
@@ -346,7 +345,8 @@ zip_convert_mail(SMFICTX *ctx, struct mailinfo *minfo, struct config *cfg,
 
 
 	        chk_replace = tmpl_tag_replace(temp, mz, p, from,
-                                               &confirmation_message, NOTICEPASS_FROM);
+                                               &confirmation_message, 
+                                               NOTICEPASS_FROM, from);
                 switch(chk_replace) {
                 case ERROR:
                     p->passwd = org_p;	/* restore original password */
@@ -378,7 +378,7 @@ zip_convert_mail(SMFICTX *ctx, struct mailinfo *minfo, struct config *cfg,
                     }
                 }
 
-	        if (passwd_sendmail(cfg, from, confirmation_message) != 0) {
+	        if (passwd_sendmail(cfg, from, confirmation_message, from) != 0) {
 	            free(confirmation_message);
 	            mailzip_clean(mz);
 	            return ZIP_CONVERT_FAILED;
@@ -524,7 +524,7 @@ zip_convert_mail(SMFICTX *ctx, struct mailinfo *minfo, struct config *cfg,
         /* パスワード通知メールの送信 */
 	temp = tmpl_init();
 
-        chk_replace = tmpl_tag_replace(temp, mz, &tmp_rcptinfo, from, &notify_message, NOTICEPASS_FROM);
+        chk_replace = tmpl_tag_replace(temp, mz, &tmp_rcptinfo, from, &notify_message, NOTICEPASS_FROM, from);
 
         switch(chk_replace) {
             case ERROR:
@@ -563,7 +563,7 @@ zip_convert_mail(SMFICTX *ctx, struct mailinfo *minfo, struct config *cfg,
          * then send passwordnotice mail to FROM */
 #ifdef __NOTICE_PASSWD
         if ((cfg->cf_passwordnotice == 0) || (cfg->cf_passwordnotice == 2)) {
-	    if (passwd_sendmail(cfg, from, notify_message) != 0) {
+	    if (passwd_sendmail(cfg, from, notify_message, from) != 0) {
 	        free(notify_message);
 	        mailzip_clean(mz);
                 free_rcptlist(rdm_all);
@@ -571,7 +571,7 @@ zip_convert_mail(SMFICTX *ctx, struct mailinfo *minfo, struct config *cfg,
 	    }
         }
 #else  // __NOTICE_PASSWD
-        if (passwd_sendmail(cfg, from, notify_message) != 0) {
+        if (passwd_sendmail(cfg, from, notify_message, from) != 0) {
             free(notify_message);
             mailzip_clean(mz);
             free_rcptlist(rdm_all);
@@ -602,7 +602,7 @@ zip_convert_mail(SMFICTX *ctx, struct mailinfo *minfo, struct config *cfg,
                 if ((cfg->cf_passwordnotice == 1) || (cfg->cf_passwordnotice == 2)) {
                     /* make notify message */
                     temp = tmpl_init();
-                    chk_replace = tmpl_tag_replace(temp, mz, rdmpasslist, rcptaddr, &notify_message_to, NOTICEPASS_TO);
+                    chk_replace = tmpl_tag_replace(temp, mz, rdmpasslist, rcptaddr, &notify_message_to, NOTICEPASS_TO, from);
 
                     switch(chk_replace) {
                     case ERROR:
@@ -624,7 +624,7 @@ zip_convert_mail(SMFICTX *ctx, struct mailinfo *minfo, struct config *cfg,
                     tmpl_release(temp);
 
                     /* send notify_password to TO */
-                    if (passwd_sendmail(cfg, rcptaddr, notify_message_to) != 0) {
+                    if (passwd_sendmail(cfg, rcptaddr, notify_message_to, from) != 0) {
                         free(notify_message_to);
                         mailzip_clean(mz);
                         return ZIP_CONVERT_FAILED;
@@ -1213,7 +1213,7 @@ parse_mail(struct mailinfo *minfo, struct config *cfg, struct mailzip *mz)
 int
 drop_file(GMimeObject *object, struct config *cfg, struct mailzip *mz)
 {
-    int ret, i, index;
+    int ret, i, index, ret_valid;
     GMimeObject *att;
     GMimeStream *w_stream;
     GMimeMessage *message;
@@ -1221,6 +1221,11 @@ drop_file(GMimeObject *object, struct config *cfg, struct mailzip *mz)
     const char *filename;
     char *p_filename, *tmpname;
     char *tmpfilename;
+    char *validatename = NULL;
+    char lastFromChar[MAX_STRCODE_LEN]; // expects strings such as "ISO-2022-JP", "EUC-JP", "SJIS", "UTF-8"
+    char *b64_tmpname = NULL;
+    char *b64_tmpfilename = NULL;
+    char *b64_validatename = NULL;
     char newfilename[PATH_MAX + 1];
     char tmppath[PATH_MAX + 1];
     int count = 0;
@@ -1320,8 +1325,25 @@ DEBUGLOG("Failed to get filename when index = %d", i);
 	    return -1;
         }
 
-	/* convert str code */
-	if (dg_str2code_replace(tmpname, &tmpfilename, STR_UTF8, cfg->cf_strcode) != 0) {
+        /* convert str code */
+        ret_valid = dg_str2code_replace_validate(tmpname, &tmpfilename, STR_UTF8,
+                        cfg->cf_strcode, &validatename, lastFromChar, MAX_STRCODE_LEN);
+        if (ret_valid != 0) {
+            /* When dg_str2code_replace_validate returns value 2,
+             * logging failure of reversal conversion validation.
+             */
+            if (ret_valid == 2) {
+                b64_tmpname = encode_b64(tmpname);
+                b64_tmpfilename = encode_b64(tmpfilename);
+                b64_validatename = encode_b64(validatename);
+                log(ERR_CONVERT_VALIDATION, b64_tmpname, 
+                    b64_tmpfilename, b64_validatename,
+                    lastFromChar, cfg->cf_strcode);
+                free(b64_tmpname);
+                free(b64_tmpfilename);
+                free(b64_validatename);
+            }
+
             /* START ADD 20150323 */
             /* If the conversion of the str2code is failed, the name of 
              * the attaching file is set by cf_attachmentfilealias.
@@ -1347,7 +1369,23 @@ DEBUGLOG("Failed to get filename when index = %d", i);
 
             /* END ADD 20150323 */
 	}
+#ifdef DEBUG
+        if (ret_valid == 0) {
+            b64_tmpname = encode_b64(tmpname);
+            b64_tmpfilename = encode_b64(tmpfilename);
+            b64_validatename = encode_b64(validatename);
+            DEBUGLOG(DEBUG_CONVERT_VALIDATION, b64_tmpname, 
+                b64_tmpfilename, b64_validatename,
+                lastFromChar, cfg->cf_strcode);
+            free(b64_tmpname);
+            free(b64_tmpfilename);
+            free(b64_validatename);
+	}
+#endif
 	free(tmpname);
+        if (validatename != NULL) {
+            free(validatename);
+        }
 
         if (ismode_delete) {
             strcpy(newfilename, tmpfilename);
